@@ -8,7 +8,8 @@ use Moose::Util::TypeConstraints;
 
 extends 'Moose::Meta::Attribute';
 
-before '_process_options' => sub
+
+sub _process_options
 {
     my $class   = shift;
     my $name    = shift;
@@ -18,12 +19,30 @@ before '_process_options' => sub
 
     $options->{default} =
         $class->_make_default_from_select
-            ( delete $options->{select},
-              delete $options->{bind_params},
+            ( $options->{select},
+              $options->{bind_params},
               $options->{isa},
             );
+
+    return $class->SUPER::_process_options( $name, $options );
 };
 
+sub _new
+{
+    my $class = shift;
+    my $options = @_ == 1 ? $_[0] : {@_};
+
+    my $self = $class->SUPER::_new($options);
+
+    $self->{select} = $options->{select};
+    $self->{bind_params} = $options->{bind_params};
+
+    return $self;
+}
+
+sub select { $_[0]->{select} }
+sub bind_params { $_[0]->{bind_params} }
+
 sub _make_default_from_select
 {
     my $class    = shift;
@@ -114,6 +133,20 @@ Note that this metaclass overrides any value you provide for "default"
 with a subroutine that executes the query and gets the value it
 returns.
 
+=head1 METHODS
+
+This class adds a few methods to those provided by
+C<Moose::Meta::Attribute>:
+
+=head2 $attr->select()
+
+Returns the C<Fey::SQL::Select> object associated with this object.
+
+=head2 $attr->bind_params()
+
+Returns the bind_params subroutine reference associated with this
+attribute, if any.
+
 =head1 ArrayRef TYPES
 
 By default, the C<SELECT> is expected to return just a single row with
