@@ -3,65 +3,37 @@ package Fey::ORM::Schema;
 use strict;
 use warnings;
 
-our @EXPORT = ## no critic ProhibitAutomaticExportation
-    qw( has_schema );
-use base 'Exporter';
-
 use Fey::Meta::Class::Schema;
 use Fey::Object::Schema;
 use Fey::Validate qw( validate_pos SCHEMA_TYPE );
 use Moose ();
+use Moose::Exporter;
+
+Moose::Exporter->setup_import_methods
+    ( with_caller => [qw( has_schema )],
+      also        => 'Moose'
+    );
 
 
-sub import
+sub init_meta
 {
-    my $caller = Moose::_get_caller();
+    shift;
+    my %p = @_;
 
-    return if $caller eq 'main';
-
-    Moose::init_meta( $caller,
-                      'Fey::Object::Schema',
-                      'Fey::Meta::Class::Schema',
-                    );
-
-    Moose->import( { into => $caller } );
-
-    __PACKAGE__->export_to_level( 1, @_ );
-
-    return;
-}
-
-sub unimport ## no critic RequireFinalReturn
-{
-    my $caller = caller();
-
-    no strict 'refs'; ## no critic ProhibitNoStrict
-    foreach my $name (@EXPORT)
-    {
-        if ( defined &{ $caller . '::' . $name } )
-        {
-            my $keyword = \&{ $caller . '::' . $name };
-
-            my $pkg_name =
-                eval { svref_2object($keyword)->GV()->STASH()->NAME() };
-
-            next if $@;
-            next if $pkg_name ne __PACKAGE__;
-
-            delete ${ $caller . '::' }{$name};
-        }
-    }
-
-    Moose::unimport( { into_level => 1 } );
+    return
+        Moose->init_meta( %p,
+                          base_class => 'Fey::Object::Schema',
+                          metaclass  => 'Fey::Meta::Class::Schema',
+                        );
 }
 
 {
     my $spec = ( SCHEMA_TYPE );
     sub has_schema
     {
-        my ($schema) = validate_pos( @_, $spec );
+        my $caller = shift;
 
-        my $caller = caller();
+        my ($schema) = validate_pos( @_, $spec );
 
         $caller->meta()->_associate_schema($schema);
     }
